# I2BMI

Mapping between ICD9 and ICD10 using CMS general equivalence mapping file (GMS) https://www.cms.gov/medicare/coding/icd10/2018-icd-10-cm-and-gems.html
2018_I9gem.txt
2018_I10gem.txt

ICD9 and ICD10 to Elixhauser Comorbidities

ICD9 and ICD10 to Phecodes
https://phewascatalog.org/phecodes
https://phewascatalog.org/phecodes_icd10cm